@@ -1,6 +1,9 @@
 package resolvers
 
 import (
+	"crypto/tls"
+	"time"
+
 	"github.com/miekg/dns"
 	"github.com/sirupsen/logrus"
 )
@@ -14,10 +17,8 @@ type ClassicResolver struct {
 
 // ClassicResolverOpts holds options for setting up a Classic resolver.
 type ClassicResolverOpts struct {
-	IPv4Only bool
-	IPv6Only bool
-	UseTLS   bool
-	UseTCP   bool
+	UseTLS bool
+	UseTCP bool
 }
 
 // NewClassicResolver accepts a list of nameservers and configures a DNS resolver.
@@ -32,15 +33,20 @@ func NewClassicResolver(server string, classicOpts ClassicResolverOpts, resolver
 		net = "tcp"
 	}
 
-	if classicOpts.IPv4Only {
+	if resolverOpts.UseIPv4 {
 		net = net + "4"
 	}
-	if classicOpts.IPv6Only {
+	if resolverOpts.UseIPv6 {
 		net = net + "6"
 	}
 
 	if classicOpts.UseTLS {
 		net = net + "-tls"
+		// Provide extra TLS config for doing/skipping hostname verification.
+		client.TLSConfig = &tls.Config{
+			ServerName:         resolverOpts.TLSHostname,
+			InsecureSkipVerify: resolverOpts.InsecureSkipVerify,
+		}
 	}
 
 	client.Net = net
@@ -65,11 +71,15 @@ func (r *ClassicResolver) Lookup(question dns.Question) (Response, error) {
 			"ndots":      r.resolverOptions.Ndots,
 			"nameserver": r.server,
 		}).Debug("Attempting to resolve")
-		in, rtt, err := r.client.Exchange(&msg, r.server)
+
+		// Since the library doesn't include tcp.Dial time,
+		// it's better to not rely on `rtt` provided here and calculate it ourselves.
+		now := time.Now()
+		in, _, err := r.client.Exchange(&msg, r.server)
 		if err != nil {
 			return rsp, err
 		}
-		// pack questions in output.
+		// Pack questions in output.
 		for _, q := range msg.Question {
 			ques := Question{
 				Name:  q.Name,
@@ -78,13 +88,15 @@ func (r *ClassicResolver) Lookup(question dns.Question) (Response, error) {
 			}
 			rsp.Questions = append(rsp.Questions, ques)
 		}
-		// get the authorities and answers.
+		rtt := time.Since(now)
+
+		// Get the authorities and answers.
 		output := parseMessage(in, rtt, r.server)
 		rsp.Authorities = output.Authorities
 		rsp.Answers = output.Answers
 
 		if len(output.Answers) > 0 {
-			// stop iterating the searchlist.
+			// Stop iterating the searchlist.
 			break
 		}
 	}
